@@ -473,7 +473,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             // payment related endpoints
             #[derive(Serialize, Deserialize, JsonSchema)]
-            struct CorrelationIdParam {
+            pub struct CorrelationIdParam {
                 correlation_id: <super::#context_type_name<'static> as PaymentProcessor>::CorrelationID
             }
 
